import { html, ref, repeat, when } from '@microsoft/fast-element';
const sideNavTemplate = html `
  <zero-flyout
    position="left"
    ?closed=${(x) => !x.sideNavOpen}
    @closed=${(x) => x.toggleNavVisibility()}
    data-test-id="side-nav"
  >
    <img
      slot="title"
      src=${(x) => x.logoSrc}
      class="logo"
      part="side-nav-logo"
      data-test-id="side-nav-logo"
    />
    <slot name="menu-contents"></slot>
    <div
      slot="footer"
      class="logout-container"
      data-test-id="logout-button"
      @click=${(x) => x.logout()}
    >
      <zero-icon name="sign-out-alt"></zero-icon>
      Sign out
    </div>
  </zero-flyout>
`;
const defaultRouteButtonsTemplate = html `
  <zero-button
    appearance="neutral-grey"
    value="1"
    @click=${(x) => x.navigateTo('protected')}
    data-test-id="home-button"
  >
    <zero-icon name="home"></zero-icon>
    Home
  </zero-button>
  <fast-option value="2" @click=${(x) => x.navigateTo('not-found')} data-test-id="profiles-button">
    <zero-icon name="users"></zero-icon>
    Profiles
  </fast-option>
`;
const routeButtonsTemplate = html `
  <template>
    ${repeat((x) => x.routeButtons, html `
        <zero-button
          appearance="neutral-grey"
          slot="routes"
          value="${(x) => x.index}"
          @click=${(x, c) => c.parent.navigateTo(x.path)}
          data-test-id="${(x) => x.testId}"
        >
          <zero-icon variant="${(x) => x.variant}" name="${(x) => x.icon}"></zero-icon>
          ${(x) => x.title}
        </zero-button>
      `)}
  </template>
`;
/**
 * Template for Navigation class
 *
 * @remarks
 *
 * Contains the template for both the sidenav and the navigation bar
 *
 * @typeParam Navigation - Navigation class
 *
 * @returns ViewTemplate instance of the Navigation html
 *
 * @public
 */
export const NavTemplate = html `
  ${when((x) => !x.hideSideBar, sideNavTemplate)}
  <div class="nav-listbox" data-test-id="nav-bar">
    <div class="nav-leftside">
      ${when((x) => !x.hideSideBar, html `
          <div
            class="bars-container"
            @click=${(x) => x.toggleNavVisibility()}
            data-test-id="hamburger-menu"
          >
            <zero-icon name="bars"></zero-icon>
          </div>
        `)}
      <div class="logo-container">
        <img src=${(x) => x.logoSrc} class="logo" part="logo" data-test-id="nav-bar-logo" />
      </div>
      <slot name="routes" data-test-id="route-buttons">
        ${(x) => (x.routeButtons ? routeButtonsTemplate : defaultRouteButtonsTemplate)}
      </slot>
    </div>
    <div class="nav-rightside">
      ${when((x) => x.showLuminanceToggleButton, html `
          <div class="icon-container" data-test-id="luminance-toggle-button">
            <zero-icon
              @click=${(x) => x.luminanceIconEvent()}
              variant="regular"
              name="moon"
            ></zero-icon>
          </div>
        `)}
      ${when((x) => x.showMiscToggleButton, html `
          <div class="icon-container" data-test-id="misc-toggle-button">
            <zero-icon @click=${(x) => x.miscIconEvent()} name="th"></zero-icon>
          </div>
        `)}
      ${when((x) => x.showNotificationsButton, html `
          <div class="icon-container" data-test-id="notifications-button">
            <zero-icon
              variant="regular"
              @click=${(x) => x.notificationIconEvent()}
              name="bell"
            ></zero-icon>
          </div>
        `)}
      ${when((x) => x.showConnectionIndicator, html `
          <div class="connection-indicator-container" data-test-id="connection-indicator">
            <zero-connection-indicator show-label="false"></zero-connection-indicator>
          </div>
        `)}
      <zero-button appearance="neutral-grey" data-test-id="user-button">
        <zero-icon name="user-circle"></zero-icon>
        ${(x) => x.userName}
      </zero-button>
    </div>
  </div>
`;
/**
 * Top level template for Navigation class
 *
 * @remarks
 *
 * Dynamic template which wraps the code in a provider
 *
 * @typeParam Navigation - Navigation class
 *
 * @returns ViewTemplate instance of the Navigation html
 *
 * @internal
 */
export const DynamicTemplate = html `
  <zero-design-system-provider ${ref('provider')}>
    <div class="dynamic-template">${(x) => x.selectTemplate()}</div>
  </zero-design-system-provider>
`;
/**
 * Loading template for the Navigation class
 *
 * @remarks
 *
 * Template used to indicate loading to the user
 *
 * @typeParam Navigation - Navigation class
 *
 * @returns ViewTemplate instance of the Loading html
 *
 * @internal
 */
export const LoadingTemplate = html `
  ...
`;
/**
 * Render template for the Navigation class
 *
 * @remarks
 *
 * Template used when the class has finished loading
 *
 * @typeParam Navigation - Navigation class
 *
 * @returns ViewTemplate instance of the Main html
 *
 * @internal
 */
export const MainTemplate = html `
  ${NavTemplate}
`;
